package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TCarTaskInspect;

/**
 * 巡检车打卡Mapper接口
 * 
 * @author zehong
 * @date 2026-05-15
 */
public interface TCarTaskInspectMapper 
{
    /**
     * 查询巡检车打卡
     * 
     * @param id 巡检车打卡ID
     * @return 巡检车打卡
     */
    public TCarTaskInspect selectTCarTaskInspectById(Long id);

    /**
     * 查询巡检车打卡列表
     * 
     * @param tCarTaskInspect 巡检车打卡
     * @return 巡检车打卡集合
     */
    public List<TCarTaskInspect> selectTCarTaskInspectList(TCarTaskInspect tCarTaskInspect);

    /**
     * 新增巡检车打卡
     * 
     * @param tCarTaskInspect 巡检车打卡
     * @return 结果
     */
    public int insertTCarTaskInspect(TCarTaskInspect tCarTaskInspect);

    /**
     * 修改巡检车打卡
     * 
     * @param tCarTaskInspect 巡检车打卡
     * @return 结果
     */
    public int updateTCarTaskInspect(TCarTaskInspect tCarTaskInspect);

    /**
     * 删除巡检车打卡
     * 
     * @param id 巡检车打卡ID
     * @return 结果
     */
    public int deleteTCarTaskInspectById(Long id);

    /**
     * 批量删除巡检车打卡
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTCarTaskInspectByIds(Long[] ids);
}
